summaryrefslogtreecommitdiff
path: root/engine
diff options
context:
space:
mode:
Diffstat (limited to 'engine')
-rw-r--r--engine/engine_flags.asm12
-rw-r--r--engine/scripting.asm11
2 files changed, 11 insertions, 12 deletions
diff --git a/engine/scripting.asm b/engine/scripting.asm
index 43af00669..756192a0d 100644
--- a/engine/scripting.asm
+++ b/engine/scripting.asm
@@ -1531,8 +1531,7 @@ Script_startbattle: ; 0x97436
; script command 0x5f
call Function2879
- ld a, PREDEF_START_BATTLE
- call Predef
+ predef StartBattle
ld a, [$d0ee]
and $3f
ld [ScriptVar], a
@@ -1545,7 +1544,7 @@ Script_catchtutorial: ; 0x97447
; byte (SingleByteParam)
call GetScriptByte
- ld [$d230], a
+ ld [BattleType], a
call Function2879
callba Function4e554
jp Script_reloadmap
@@ -1573,8 +1572,8 @@ Script_returnafterbattle: ; 0x97459
ld a, [$d0ee]
bit 7, a
jr z, .asm_9748e ; 0x97481 $b
- ld b, $24
- ld de, $4255
+ ld b, BANK(UnknownScript_0x90255)
+ ld de, UnknownScript_0x90255
callba Function97c4f
.asm_9748e
jp Script_reloadmap
@@ -2659,7 +2658,7 @@ Script_giveegg: ; 0x97968
ld [CurPartySpecies], a
call GetScriptByte
ld [CurPartyLevel], a
- callba Functiondf8c
+ callba GiveEgg
ret nc
ld a, $2
ld [ScriptVar], a
diff --git a/engine/engine_flags.asm b/engine/engine_flags.asm
index 11414438e..34f26c87c 100644
--- a/engine/engine_flags.asm
+++ b/engine/engine_flags.asm
@@ -9,13 +9,13 @@
dwb $d957, %00001000 ; expn card
dwb $d957, %10000000 ; on/off
- ; DaycareMan, %10000000 ; daycare 1 on
- dwb DaycareMan, %01000000 ; monster 1 and 2 are compatible
- ; DaycareMan, %00100000 ; egg is ready
- dwb DaycareMan, %00000001 ; monster 1 in daycare
+ ; wDaycareMan, %10000000 ; daycare 1 on
+ dwb wDaycareMan, %01000000 ; monster 1 and 2 are compatible
+ ; wDaycareMan, %00100000 ; egg is ready
+ dwb wDaycareMan, %00000001 ; monster 1 in daycare
- ; DaycareLady, %10000000 = daycare 2 on
- dwb DaycareLady, %00000001 ; monster 2 in daycare
+ ; wDaycareLady, %10000000 = daycare 2 on
+ dwb wDaycareLady, %00000001 ; monster 2 in daycare
dwb $d854, %00000001 ; mom saving money ; $8
dwb $d854, %10000000 ; dst